"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const controller_1 = require("@curveball/controller");
const privilegeService = require("../../privilege/service");
const hal = require("../formats/hal");
const principalService = require("../../principal/service");
const groupService = require("../../group/service");
const http_errors_1 = require("@curveball/http-errors");
class AppController extends controller_1.default {
    async get(ctx) {
        const app = await principalService.findById(+ctx.params.id, 'app');
        const isAdmin = await privilegeService.hasPrivilege(ctx, 'admin');
        ctx.response.body = hal.item(app, await privilegeService.getPrivilegesForPrincipal(app), isAdmin, await groupService.findGroupsForPrincipal(app));
    }
    async put(ctx) {
        if (!await privilegeService.hasPrivilege(ctx, 'admin')) {
            throw new http_errors_1.Forbidden('Only users with the "admin" privilege may edit users');
        }
        ctx.request.validate('https://curveballjs.org/schemas/a12nserver/principal-edit.json');
        const user = await principalService.findById(+ctx.params.id, 'app');
        user.active = !!ctx.request.body.active;
        user.nickname = ctx.request.body.nickname;
        await principalService.save(user);
        ctx.status = 204;
    }
}
exports.default = new AppController();
//# sourceMappingURL=item.js.map