"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.item = exports.collection = void 0;
function collection(apps) {
    const hal = {
        _links: {
            'self': { href: '/app' },
            'item': apps.map(app => ({
                href: app.href,
                title: app.nickname,
            })),
            'create-form': { href: '/create-user', title: 'Add new App' },
        },
        total: apps.length,
    };
    return hal;
}
exports.collection = collection;
/**
 * Generate a HAL response for a specific app
 *
 * hasControl should only be true if the *current* user is same as the user
 * we're generating the repsonse for, or if the current authenticated user
 * has full admin privileges
 */
function item(app, privileges, isAdmin, groups) {
    const hal = {
        _links: {
            'self': { href: app.href, title: app.nickname },
            'me': { href: app.identity, title: app.nickname },
            'up': { href: '/app', title: 'List of apps' },
            'group': groups.map(group => ({
                href: group.href,
                title: group.nickname,
            })),
            'client-collection': {
                href: `${app.href}/client`,
                title: 'List of OAuth2 client credentials'
            }
        },
        nickname: app.nickname,
        active: app.active,
        createdAt: app.createdAt,
        modifiedAt: app.modifiedAt,
        type: app.type,
        privileges
    };
    if (isAdmin) {
        hal._links['privileges'] = {
            href: `${app.href}/edit/privileges`,
            title: 'Change privilege policy',
        };
    }
    return hal;
}
exports.item = item;
//# sourceMappingURL=hal.js.map