"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateSecretToken = void 0;
const crypto_1 = require("crypto");
/**
 * Centralized place for all crypto-related functions
 */
/**
 * Returns a secret, opaque token.
 *
 * The token will use the characters from the base64url character list, which
 * is url-safe.
 */
function generateSecretToken(bytes = 32) {
    return new Promise((res, rej) => {
        crypto_1.randomBytes(bytes, (err, buf) => {
            if (err) {
                rej(err);
                return;
            }
            const base64Url = buf.toString('base64')
                .replace(/\+/g, '-') // + -> -
                .replace(/\//g, '_') // / -> _
                .replace(/=/g, ''); // Strip =
            res(base64Url);
        });
    });
}
exports.generateSecretToken = generateSecretToken;
//# sourceMappingURL=crypto.js.map