"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.checkPatches = exports.query = exports.getConnection = void 0;
/* eslint no-console: 0 */
const mysql = require("mysql2/promise");
const promises_1 = require("fs/promises");
const path_1 = require("path");
let pool;
async function getPool() {
    if (!pool) {
        pool = mysql.createPool(await getSettings());
    }
    return pool;
}
async function getConnection() {
    return (await getPool()).getConnection();
}
exports.getConnection = getConnection;
async function query(query, params) {
    return (await getPool()).query(query, params);
}
exports.query = query;
async function checkPatches() {
    // Get a list of known database patches.
    const files = await promises_1.readdir(path_1.join(__dirname, '..', 'mysql-schema'));
    const patches = new Map();
    for (const file of files) {
        const match = file.match(/^([0-9]+)-.*\.sql$/);
        if (!match)
            continue;
        patches.set(parseInt(match[1]), file);
    }
    const result = await query('SELECT id FROM changelog');
    for (const { id } of result[0]) {
        if (!patches.has(id)) {
            console.warn('Warning! Found an unknown database patch in the changelog. Patch id: ' + id);
        }
        patches.delete(id);
    }
    if (patches.size > 0) {
        console.error('Error!! Database patches have not been applied. Please run the following .sql scripts:');
        for (const fileName of patches.values()) {
            console.error(`  - ${fileName}`);
        }
        throw new Error('Missing patches');
    }
}
exports.checkPatches = checkPatches;
exports.default = {
    query,
    getConnection,
    checkPatches,
};
async function getSettings() {
    let settings = {};
    // We are running in a local environment.
    settings = {
        user: process.env.MYSQL_USER,
        password: process.env.MYSQL_PASSWORD,
        database: process.env.MYSQL_DATABASE,
    };
    if (process.env.MYSQL_INSTANCE_CONNECTION_NAME) {
        settings.socketPath = '/cloudsql/' + process.env.MYSQL_INSTANCE_CONNECTION_NAME;
    }
    else {
        settings.host = process.env.MYSQL_HOST;
        settings.port = process.env.MYSQL_PORT || 3306;
    }
    return settings;
}
//# sourceMappingURL=database.js.map