"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const controller_1 = require("@curveball/controller");
const privilegeService = require("../../privilege/service");
const hal = require("../formats/hal");
const principalService = require("../../principal/service");
const groupService = require("../../group/service");
const http_errors_1 = require("@curveball/http-errors");
class GroupController extends controller_1.default {
    async get(ctx) {
        const group = await principalService.findById(+ctx.params.id, 'group');
        const isAdmin = await privilegeService.hasPrivilege(ctx, 'admin');
        const members = await groupService.findMembers(group);
        ctx.response.body = hal.item(group, await privilegeService.getPrivilegesForPrincipal(group), isAdmin, await groupService.findGroupsForPrincipal(group), members);
    }
    async put(ctx) {
        if (!await privilegeService.hasPrivilege(ctx, 'admin')) {
            throw new http_errors_1.Forbidden('Only users with the "admin" privilege may edit users');
        }
        ctx.request.validate('https://curveballjs.org/schemas/a12nserver/principal-edit.json');
        const user = await principalService.findById(+ctx.params.id, 'group');
        user.active = !!ctx.request.body.active;
        user.nickname = ctx.request.body.nickname;
        await principalService.save(user);
        ctx.status = 204;
    }
    /**
     * The POST request here is a simpler rpc-like API to add or remove members
     * from a group.
     */
    async patch(ctx) {
        ctx.request.validate('https://curveballjs.org/schemas/a12nserver/group-patch.json');
        const group = await principalService.findById(+ctx.params.id, 'group');
        const memberHref = ctx.request.body.memberHref;
        let member;
        try {
            member = await principalService.findByHref(memberHref);
        }
        catch (err) {
            if (err instanceof http_errors_1.NotFound) {
                throw new http_errors_1.Conflict(`User with href ${memberHref} not found`);
            }
            else {
                throw err;
            }
        }
        switch (ctx.request.body.operation) {
            case 'add-member':
                await groupService.addMember(group, member);
                break;
            case 'remove-member':
                await groupService.removeMember(group, member);
                break;
        }
        if (ctx.request.accepts('text/html')) {
            ctx.redirect(303, group.href);
        }
        else {
            ctx.status = 204;
        }
    }
}
exports.default = new GroupController();
//# sourceMappingURL=item.js.map