"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.findGroupsForPrincipal = exports.removeMember = exports.replaceMembers = exports.addMember = exports.findMembers = void 0;
const database_1 = require("../database");
const principalService = require("../principal/service");
/**
 * Finding group members
 */
async function findMembers(group) {
    const query = `SELECT ${principalService.fieldNames.join(', ')} FROM principals INNER JOIN group_members ON principals.id = group_members.user_id WHERE group_id = ?`;
    const result = await database_1.default.query(query, [group.id]);
    const models = [];
    for (const record of result[0]) {
        const model = principalService.recordToModel(record);
        models.push(model);
    }
    return models;
}
exports.findMembers = findMembers;
async function addMember(group, user) {
    const query = 'INSERT INTO group_members SET group_id = ?, user_id = ?';
    await database_1.default.query(query, [group.id, user.id]);
}
exports.addMember = addMember;
async function replaceMembers(group, users) {
    const connection = await database_1.default.getConnection();
    await connection.beginTransaction();
    try {
        await connection.query('DELETE FROM group_members WHERE group_id = ?', [group.id]);
        for (const user of users) {
            await connection.query('INSERT INTO group_members SET group_id = ?, user_id = ?', [group.id, user.id]);
        }
        await connection.commit();
    }
    catch (err) {
        await connection.rollback();
        throw err;
    }
    finally {
        connection.release();
    }
}
exports.replaceMembers = replaceMembers;
async function removeMember(group, user) {
    const query = 'DELETE FROM group_members WHERE group_id = ? AND user_id = ?';
    await database_1.default.query(query, [group.id, user.id]);
}
exports.removeMember = removeMember;
/**
 * Finding group members
 */
async function findGroupsForPrincipal(principal) {
    const query = `SELECT ${principalService.fieldNames.join(', ')} FROM principals INNER JOIN group_members ON principals.id = group_members.group_id WHERE user_id = ?`;
    const result = await database_1.default.query(query, [principal.id]);
    const models = [];
    for (const record of result[0]) {
        const model = principalService.recordToModel(record);
        models.push(model);
    }
    return models;
}
exports.findGroupsForPrincipal = findGroupsForPrincipal;
//# sourceMappingURL=service.js.map