"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const controller_1 = require("@curveball/controller");
const http_errors_1 = require("@curveball/http-errors");
const privilegeService = require("../../privilege/service");
const principalService = require("../../principal/service");
const csv_1 = require("../formats/csv");
const logService = require("../service");
class UserLogController extends controller_1.default {
    async get(ctx) {
        const user = await principalService.findById(+ctx.params.id);
        const log = await logService.findByUser(user);
        if (user.id !== ctx.state.user.id) {
            if (!await privilegeService.hasPrivilege(ctx, 'admin')) {
                throw new http_errors_1.Forbidden('Only users with the "admin" privilege may inspect other users\' logs');
            }
        }
        ctx.response.type = 'text/csv';
        ctx.response.headers.append('Link', [
            `</user/${user.id}>; rel=up; title="Back to user"`,
        ]);
        ctx.response.body = csv_1.default(log);
    }
}
exports.default = new UserLogController();
//# sourceMappingURL=user.js.map