"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const controller_1 = require("@curveball/controller");
const querystring = require("querystring");
const utilities_1 = require("../utilities");
const html_1 = require("../formats/html");
const service_1 = require("../../log/service");
const types_1 = require("../../log/types");
const userService = require("../../user/service");
class MFAController extends controller_1.default {
    async get(ctx) {
        const { user, mfaType } = ctx.session.mfa || {};
        if (!user) {
            return this.redirectToLogin(ctx);
        }
        const useTotp = mfaType === 'totp';
        const useWebAuthn = mfaType === 'webauthn';
        ctx.response.type = 'text/html';
        ctx.response.body = html_1.mfaForm(ctx.query.msg, ctx.query.error, useTotp, useWebAuthn, {
            continue: ctx.query.continue,
        });
    }
    async post(ctx) {
        const { user } = ctx.session.mfa || {};
        if (!user) {
            return this.redirectToLogin(ctx);
        }
        if (ctx.request.body.totp) {
            if (!await userService.validateTotp(user, ctx.request.body.totp)) {
                service_1.default(types_1.EventType.totpFailed, ctx.ip(), user.id);
                return this.redirectToMfa(ctx, 'Incorrect TOTP code');
            }
        }
        else {
            return this.redirectToMfa(ctx, 'TOTP token required');
        }
        if (ctx.request.body.continue && !utilities_1.isValidRedirect(ctx.request.body.continue)) {
            return this.redirectToMfa(ctx, 'Invalid continue URL provided');
        }
        ctx.session = {
            user: user,
        };
        service_1.default(types_1.EventType.loginSuccess, ctx);
        ctx.status = 303;
        if (ctx.request.body.continue) {
            ctx.response.headers.set('Location', ctx.request.body.continue);
            return;
        }
        ctx.response.headers.set('Location', '/');
    }
    async redirectToMfa(ctx, error) {
        ctx.response.status = 303;
        ctx.response.headers.set('Location', '/login/mfa?' + querystring.stringify({ error }));
    }
    async redirectToLogin(ctx) {
        ctx.response.status = 303;
        ctx.response.headers.set('Location', '/login');
    }
}
exports.default = new MFAController();
//# sourceMappingURL=mfa.js.map