"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.recordToModel = exports.hasWebauthn = exports.findDeviceByUserAndId = exports.findDevicesByUser = exports.save = void 0;
const http_errors_1 = require("@curveball/http-errors");
const database_1 = require("../../database");
async function save(webAuthNDevice) {
    if (!isExistingDevice(webAuthNDevice)) {
        const query = 'INSERT INTO user_webauthn SET ?, created = UNIX_TIMESTAMP()';
        const newWebAuthnRecord = {
            user_id: webAuthNDevice.user.id,
            credential_id: webAuthNDevice.credentialID.toString('base64'),
            public_key: webAuthNDevice.publicKey.toString('base64'),
            counter: webAuthNDevice.counter
        };
        const result = await database_1.default.query(query, [newWebAuthnRecord]);
        return {
            id: result[0].insertId,
            ...webAuthNDevice
        };
    }
    else {
        const query = 'UPDATE user_webauthn SET ? WHERE id = ?';
        const updateWebAuthnRecord = {
            credential_id: webAuthNDevice.credentialID.toString('base64'),
            public_key: webAuthNDevice.publicKey.toString('base64'),
            counter: webAuthNDevice.counter
        };
        await database_1.default.query(query, [updateWebAuthnRecord, webAuthNDevice.id]);
        return webAuthNDevice;
    }
}
exports.save = save;
async function findDevicesByUser(user) {
    const query = 'SELECT id, credential_id, public_key, counter FROM user_webauthn WHERE user_id = ?';
    const result = await database_1.default.query(query, [user.id]);
    return result[0].map((row) => recordToModel(row, user));
}
exports.findDevicesByUser = findDevicesByUser;
async function findDeviceByUserAndId(user, credentialId) {
    const query = 'SELECT id, credential_id, public_key, counter FROM user_webauthn WHERE user_id = ? and credential_id = ?';
    const result = await database_1.default.query(query, [user.id, credentialId]);
    if (result[0].length !== 1) {
        throw new http_errors_1.NotFound('Device with id: ' + credentialId + ' not found');
    }
    return recordToModel(result[0][0], user);
}
exports.findDeviceByUserAndId = findDeviceByUserAndId;
async function hasWebauthn(user) {
    const query = 'SELECT credential_id FROM user_webauthn WHERE user_id = ?';
    const result = await database_1.default.query(query, [user.id]);
    return result[0].length !== 0;
}
exports.hasWebauthn = hasWebauthn;
function recordToModel(userWebAuthn, user) {
    return {
        id: userWebAuthn.id,
        user: user,
        credentialID: Buffer.from(userWebAuthn.credential_id, 'base64'),
        publicKey: Buffer.from(userWebAuthn.public_key, 'base64'),
        counter: userWebAuthn.counter,
    };
}
exports.recordToModel = recordToModel;
function isExistingDevice(device) {
    return device.id !== undefined;
}
//# sourceMappingURL=service.js.map