"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const controller_1 = require("@curveball/controller");
const privilegeService = require("../../privilege/service");
const hal = require("../formats/hal");
const http_errors_1 = require("@curveball/http-errors");
const service_1 = require("../service");
const principalService = require("../../principal/service");
const oauth2Service = require("../../oauth2/service");
class ClientController extends controller_1.default {
    async get(ctx) {
        const user = await principalService.findById(+ctx.params.id, 'app');
        if (user.id !== ctx.state.user.id) {
            if (!await privilegeService.hasPrivilege(ctx, 'admin')) {
                throw new http_errors_1.Forbidden('Only users with the "admin" privilege can inspect OAuth2 clients that are not your own');
            }
        }
        const client = await service_1.findByClientId(ctx.params.clientId);
        if (client.app.id !== user.id) {
            throw new http_errors_1.NotFound('OAuth2 client not found');
        }
        ctx.response.body = hal.item(client, await oauth2Service.getRedirectUris(client));
    }
}
exports.default = new ClientController();
//# sourceMappingURL=item.js.map