"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const controller_1 = require("@curveball/controller");
const http_errors_1 = require("@curveball/http-errors");
const service_1 = require("../../log/service");
const types_1 = require("../../log/types");
const principalService = require("../../principal/service");
const oauth2Service = require("../service");
const privilegeService = require("../../privilege/service");
class UserAccessTokenController extends controller_1.default {
    async post(ctx) {
        const user = await principalService.findById(+ctx.params.id);
        if (ctx.state.user.id !== user.id && !await privilegeService.hasPrivilege(ctx, 'admin')) {
            throw new http_errors_1.Forbidden('You can only generate OAuth2 access tokens for yourself with this endpoint (unless you have the \'admin\' privilege (which you haven\'t))');
        }
        if (user.type !== 'user') {
            throw new http_errors_1.BadRequest('This API can only be used for principals of type \'user\'');
        }
        const token = await oauth2Service.generateTokenForUserNoClient(user);
        ctx.response.body = {
            access_token: token.accessToken,
            token_type: token.tokenType,
            expires_in: token.accessTokenExpires - Math.round(Date.now() / 1000),
        };
        service_1.default(types_1.EventType.generateAccessToken, ctx.ip(), user.id, ctx.request.headers.get('User-Agent'));
    }
}
exports.default = new UserAccessTokenController();
//# sourceMappingURL=user-access-token.js.map