"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TemporarilyUnavailable = exports.ServerError = exports.UnsupportedGrantType = exports.InvalidGrant = exports.InvalidClient = exports.InvalidScope = exports.UnsupportedResponseType = exports.AccessDenied = exports.UnauthorizedClient = exports.InvalidRequest = exports.isOAuth2Error = void 0;
function isOAuth2Error(err) {
    return typeof err.errorCode === 'string';
}
exports.isOAuth2Error = isOAuth2Error;
/**
 * The request is missing a required parameter, includes an invalid parameter
 * value, includes a parameter more than once or is otherwise malformed.
 */
class InvalidRequest extends Error {
    constructor() {
        super(...arguments);
        this.httpStatus = 400;
        this.errorCode = 'invalid_request';
    }
}
exports.InvalidRequest = InvalidRequest;
/**
 * The client is not authorized to request an authorization code using this
 * method
 */
class UnauthorizedClient extends Error {
    constructor() {
        super(...arguments);
        this.httpStatus = 403;
        this.errorCode = 'unauthorized_client';
    }
}
exports.UnauthorizedClient = UnauthorizedClient;
/**
 * The resource owner or authorization server denied the request
 */
class AccessDenied extends Error {
    constructor() {
        super(...arguments);
        this.httpStatus = 403;
        this.errorCode = 'access_denied';
    }
}
exports.AccessDenied = AccessDenied;
/**
 * The authorization server does not support obtaining an authorization code
 * using this method
 */
class UnsupportedResponseType extends Error {
    constructor() {
        super(...arguments);
        this.httpStatus = 400;
        this.errorCode = 'unsupported_response_type';
    }
}
exports.UnsupportedResponseType = UnsupportedResponseType;
/**
 * The requested scope is invalid, unknown or malformed
 */
class InvalidScope extends Error {
    constructor() {
        super(...arguments);
        this.httpStatus = 400;
        this.errorCode = 'invalid_scope';
    }
}
exports.InvalidScope = InvalidScope;
/**
 * Client authentication failed (e.g., unknown client, no client authentication
 * included, or unsupported authentication method).  The authorization server
 * MAY return an HTTP 401 (Unauthorized) status code to indicate which HTTP
 * authentication schemes are supported.  If the client attempted to
 * authenticate via the "Authorization" request header field, the authorization
 * server MUST respond with an HTTP 401 (Unauthorized) status code and include
 * the "WWW-Authenticate" response header field matching the authentication
 * scheme used by the client.
 */
class InvalidClient extends Error {
    constructor() {
        super(...arguments);
        this.httpStatus = 401;
        this.errorCode = 'invalid_client';
    }
}
exports.InvalidClient = InvalidClient;
/**
 * The provided authorization grant (e.g., authorization code, resource owner
 * credentials) or refresh token is invalid, expired, revoked, does not match
 * the redirection URI used in the authorization request, or was issued to
 * another client.
 */
class InvalidGrant extends Error {
    constructor() {
        super(...arguments);
        this.httpStatus = 400;
        this.errorCode = 'invalid_grant';
    }
}
exports.InvalidGrant = InvalidGrant;
/**
 * The authorization grant type is not supported by the authorization server.
 */
class UnsupportedGrantType extends Error {
    constructor() {
        super(...arguments);
        this.httpStatus = 400;
        this.errorCode = 'unsupported_grant_type';
    }
}
exports.UnsupportedGrantType = UnsupportedGrantType;
/**
 * The authorization server encountered an unexpected condition that prevented
 * it from fulfilling the request. (This error code is needed because a 500
 * Internal Server Error HTTP status code cannot be returned to the client via
 * an HTTP redirect.)
 */
class ServerError extends Error {
    constructor() {
        super(...arguments);
        this.httpStatus = 500;
        this.errorCode = 'server_error';
    }
}
exports.ServerError = ServerError;
/**
 * The authorization server is currently unable to handle the request due to a
 * temporary overloading or maintenance of the server.  (This error code is
 * needed because a 503 Service Unavailable HTTP status code cannot be returned
 * to the client via an HTTP redirect.)
 */
class TemporarilyUnavailable extends Error {
    constructor() {
        super(...arguments);
        this.httpStatus = 503;
        this.errorCode = 'temporarily_unavailable';
    }
}
exports.TemporarilyUnavailable = TemporarilyUnavailable;
//# sourceMappingURL=errors.js.map