"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateJWTAccessToken = void 0;
const crypto_1 = require("../crypto");
const jwt = require("jsonwebtoken");
const url_1 = require("url");
async function generateJWTAccessToken(user, client, expiry, scopes) {
    if (!process.env.JWT_PRIVATE_KEY) {
        throw new Error('The JWT_PRIVATE_KEY environment variable must be set, and must be a RSA private key file (typically a .pem file)');
    }
    const origin = process.env.PUBLIC_URI;
    const jti = await crypto_1.generateSecretToken();
    // Some environment variable systems will convert the newline to a literal '\n'.
    // this is a safe operation, because the file should not contain any literal
    // backslashes.
    const privateKey = process.env.JWT_PRIVATE_KEY.replace(/\\n/gm, '\n');
    const jwtBody = {
        iss: origin,
        exp: Math.floor(Date.now() / 1000) + expiry,
        aud: url_1.resolve(origin, '/app/' + client.app.id),
        sub: url_1.resolve(origin, '/user/' + user.id),
        client_id: client.clientId,
        iat: Math.floor(Date.now() / 1000),
        jti,
        scope: scopes.join(' '),
    };
    const jwtOptions = {
        algorithm: 'RS256',
    };
    return new Promise((res, rej) => {
        jwt.sign(jwtBody, privateKey, jwtOptions, (err, result) => {
            if (err) {
                rej(err);
                return;
            }
            else {
                res(result);
            }
        });
    });
}
exports.generateJWTAccessToken = generateJWTAccessToken;
//# sourceMappingURL=jwt.js.map