"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const controller_1 = require("@curveball/controller");
const http_errors_1 = require("@curveball/http-errors");
const json_1 = require("../../oauth2/formats/json");
const privilegeService = require("../../privilege/service");
const tokenService = require("../service");
const oauth2Service = require("../../oauth2/service");
const oauth2ClientService = require("../../oauth2-client/service");
const principalService = require("../../principal/service");
class OneTimeTokenExchangeController extends controller_1.default {
    async post(ctx) {
        if (!await privilegeService.hasPrivilege(ctx, 'admin')) {
            throw new http_errors_1.Forbidden('Only users with the "admin" privilege use this endpoint');
        }
        if (!ctx.request.body.token) {
            throw new http_errors_1.UnprocessableEntity('A token must be provided for the exchange');
        }
        if (!ctx.request.body.client_id) {
            throw new http_errors_1.UnprocessableEntity('A client_id must be provided for the exchange');
        }
        const user = await tokenService.validateToken(ctx.request.body.token);
        if (!user.active) {
            if (ctx.request.body.activateUser) {
                user.active = true;
                await principalService.save(user);
            }
            else {
                throw new http_errors_1.Forbidden('The user associated with the one-time-token has been deactivated. Either activate the user first, or provide the "activateUser" property in the request if the intent is to activate the user with the one-time-token mechanism');
            }
        }
        const client = await oauth2ClientService.findByClientId(ctx.request.body.client_id);
        const oauth2Token = await oauth2Service.generateTokenForUser(client, user);
        ctx.response.body = json_1.tokenResponse(oauth2Token);
    }
}
exports.default = new OneTimeTokenExchangeController();
//# sourceMappingURL=exchange.js.map