"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const controller_1 = require("@curveball/controller");
const privilegeService = require("../../privilege/service");
const http_errors_1 = require("@curveball/http-errors");
const principalService = require("../../principal/service");
const service_1 = require("../service");
const hal = require("../formats/hal");
const url_1 = require("url");
class OneTimeTokenController extends controller_1.default {
    async post(ctx) {
        if (!await privilegeService.hasPrivilege(ctx, 'admin')) {
            throw new http_errors_1.Forbidden('Only users with the "admin" privilege can request for one time token');
        }
        const user = await principalService.findById(ctx.state.params.id);
        if (user.type !== 'user') {
            throw new http_errors_1.Forbidden('One-time token may only be obtained for users');
        }
        const token = await service_1.createToken(user);
        const url = url_1.resolve(process.env.PUBLIC_URI, 'reset-password/token/' + token.token);
        ctx.response.body = hal.oneTimeToken(user, url, token);
    }
}
exports.default = new OneTimeTokenController();
//# sourceMappingURL=generate.js.map