"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const controller_1 = require("@curveball/controller");
const http_errors_1 = require("@curveball/http-errors");
const server_settings_1 = require("../../server-settings");
const principalService = require("../../principal/service");
const userService = require("../../user/service");
const html_1 = require("../formats/html");
const privilegeService = require("../../privilege/service");
class UserRegistrationController extends controller_1.default {
    async get(ctx) {
        const firstRun = !(await principalService.hasPrincipals());
        ctx.response.type = 'text/html';
        ctx.response.body = html_1.registrationForm(ctx.query.msg, ctx.query.error, server_settings_1.getSetting('registration.mfa.enabled'), firstRun);
    }
    async post(ctx) {
        const body = ctx.request.body;
        const userPassword = body.password;
        const confirmPassword = body.confirmPassword;
        const addMfa = 'addMfa' in body;
        if (userPassword !== confirmPassword) {
            ctx.status = 303;
            ctx.response.headers.set('Location', '/register?error=Password+mismatch.+Please+try+again');
            return;
        }
        try {
            await principalService.findByIdentity('mailto:' + body.emailAddress);
            ctx.status = 303;
            ctx.response.headers.set('Location', '/register?error=User+already+exists');
            return;
        }
        catch (err) {
            if (!(err instanceof http_errors_1.NotFound)) {
                throw err;
            }
        }
        const firstRun = !(await principalService.hasPrincipals());
        const user = await principalService.save({
            identity: 'mailto:' + body.emailAddress,
            nickname: body.nickname,
            createdAt: new Date(),
            modifiedAt: new Date(),
            type: 'user',
            // Auto-activating if it's the first user.
            active: firstRun,
        });
        if (firstRun) {
            // The first user will be an admin
            await privilegeService.addPrivilegeForUser(user, 'admin', '*');
        }
        await userService.createPassword(user, userPassword);
        if (addMfa && server_settings_1.getSetting('registration.mfa.enabled')) {
            ctx.session = {
                registerUser: user,
            };
            ctx.response.status = 303;
            ctx.response.headers.set('Location', '/register/mfa');
            return;
        }
        ctx.status = 303;
        ctx.response.headers.set('Location', '/login?msg=Registration+successful.+Please log in');
    }
    async dispatch(ctx) {
        if (!server_settings_1.getSetting('registration.enabled')) {
            throw new http_errors_1.Forbidden('This feature is disabled');
        }
        return super.dispatch(ctx);
    }
}
exports.default = new UserRegistrationController();
//# sourceMappingURL=user.js.map