"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.sendResetPasswordEmail = void 0;
const nodemailer = require("nodemailer");
const templates_1 = require("../templates");
const service_1 = require("../one-time-token/service");
/**
 * This function is for sending reset password email with validated token
 *
 * This flow, it will first check if email and URL environment variable has been set.
 *
 * Renders an email with provided from, to, subject, html template.
 */
async function sendResetPasswordEmail(user) {
    if (!process.env.SMTP_EMAIL_FROM) {
        throw new Error('The environment variable SMTP_EMAIL_FROM must be set');
    }
    if (!process.env.SMTP_URL) {
        throw new Error('The environment variable SMTP_URL must be set. Needs to contain "smtps://[Username]:[Password]@[Host]:[Port]"');
    }
    const transporter = nodemailer.createTransport(process.env.SMTP_URL);
    const token = await service_1.createToken(user);
    const emailTemplate = templates_1.render('emails/reset-password-email', {
        name: user.nickname,
        url: process.env.PUBLIC_URI + 'reset-password/token/' + token.token,
        expiryHours: token.ttl / 60 / 60
    });
    // send mail with defined transport object
    const info = await transporter.sendMail({
        from: process.env.SMTP_EMAIL_FROM,
        to: user.identity.substring(7),
        subject: 'Password reset request',
        html: emailTemplate
    });
    nodemailer.getTestMessageUrl(info);
}
exports.sendResetPasswordEmail = sendResetPasswordEmail;
//# sourceMappingURL=service.js.map