"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.load = exports.getSetting = void 0;
const settingsCache = new Map();
let settingsLoaded = false;
const database_1 = require("./database");
function getSetting(setting, deflt) {
    if (!settingsLoaded) {
        throw new Error('Settings have not been loaded. Call load() first');
    }
    const value = settingsCache.get(setting);
    if (value === undefined || value === null) {
        if (deflt === undefined) {
            throw new Error(`Setting ${setting} not found`);
        }
        return deflt;
    }
    else {
        return value;
    }
}
exports.getSetting = getSetting;
/**
 * Loads or reloads settings from the database.
 */
async function load() {
    const query = 'SELECT setting, value FROM server_settings';
    const result = await database_1.default.query(query);
    for (const row of result[0]) {
        settingsCache.set(row.setting, JSON.parse(row.value));
    }
    settingsLoaded = true;
}
exports.load = load;
//# sourceMappingURL=server-settings.js.map