"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const controller_1 = require("@curveball/controller");
const privilegeService = require("../../privilege/service");
const userHal = require("../formats/hal");
const appHal = require("../../app/formats/hal");
const groupHal = require("../../group/formats/hal");
const principalService = require("../../principal/service");
const userService = require("../service");
const groupService = require("../../group/service");
class UserByHrefController extends controller_1.default {
    async get(ctx) {
        const principal = await principalService.findByHref(decodeURIComponent(ctx.params.href));
        let hasControl = false;
        let hasPassword = false;
        const isAdmin = await privilegeService.hasPrivilege(ctx, 'admin');
        if (ctx.state.user.id === principal.id) {
            hasControl = true;
        }
        else if (isAdmin) {
            hasControl = true;
        }
        if (hasControl && principal.type === 'user') {
            hasPassword = await userService.hasPassword(principal);
        }
        // This endpoint supports rendering groups and apps, for backwards
        // compatibility. This will be removed in the future
        switch (principal.type) {
            case 'user':
                ctx.response.body = userHal.item(principal, await privilegeService.getPrivilegesForPrincipal(principal), hasControl, hasPassword, isAdmin, await groupService.findGroupsForPrincipal(principal));
                break;
            case 'group': {
                const members = await groupService.findMembers(principal);
                ctx.response.body = groupHal.item(principal, await privilegeService.getPrivilegesForPrincipal(principal), isAdmin, await groupService.findGroupsForPrincipal(principal), members);
                break;
            }
            case 'app':
                ctx.response.body = appHal.item(principal, await privilegeService.getPrivilegesForPrincipal(principal), isAdmin, await groupService.findGroupsForPrincipal(principal));
                break;
        }
    }
}
exports.default = new UserByHrefController();
//# sourceMappingURL=by-href.js.map