"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const controller_1 = require("@curveball/controller");
const http_errors_1 = require("@curveball/http-errors");
const privilegeService = require("../../privilege/service");
const hal = require("../formats/hal");
const principalService = require("../../principal/service");
class UserCollectionController extends controller_1.default {
    async get(ctx) {
        const users = await principalService.findAll('user');
        ctx.response.body = hal.collection(users);
    }
    async post(ctx) {
        var _a;
        if (!await privilegeService.hasPrivilege(ctx, 'admin')) {
            throw new http_errors_1.Forbidden('Only users with the "admin" privilege may create new users');
        }
        ctx.request.validate('https://curveballjs.org/schemas/a12nserver/principal-new.json');
        const identity = (_a = ctx.request.links.get('me')) === null || _a === void 0 ? void 0 : _a.href;
        if (!identity) {
            throw new http_errors_1.BadRequest('You must specify a link with rel "me", either via a HAL link or HTTP Link header');
        }
        try {
            await principalService.findByIdentity(identity);
            throw new http_errors_1.Conflict('User already exists');
        }
        catch (err) {
            if (!(err instanceof http_errors_1.NotFound)) {
                throw err;
            }
        }
        const user = await principalService.save({
            identity,
            nickname: ctx.request.body.nickname,
            type: ctx.request.body.type,
            active: ctx.request.body.active,
            createdAt: new Date(),
            modifiedAt: new Date(),
        });
        ctx.response.status = 201;
        ctx.response.headers.set('Location', `/user/${user.id}`);
    }
}
exports.default = new UserCollectionController();
//# sourceMappingURL=collection.js.map