"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const controller_1 = require("@curveball/controller");
const privilegeService = require("../../privilege/service");
const userHal = require("../formats/hal");
const appHal = require("../../app/formats/hal");
const groupHal = require("../../group/formats/hal");
const userService = require("../service");
const principalService = require("../../principal/service");
const groupService = require("../../group/service");
const http_errors_1 = require("@curveball/http-errors");
class UserController extends controller_1.default {
    async get(ctx) {
        const principal = await principalService.findById(+ctx.params.id);
        let hasControl = false;
        let hasPassword = false;
        const isAdmin = await privilegeService.hasPrivilege(ctx, 'admin');
        if (ctx.state.user.id === principal.id) {
            hasControl = true;
        }
        else if (isAdmin) {
            hasControl = true;
        }
        if (hasControl && principal.type === 'user') {
            hasPassword = await userService.hasPassword(principal);
        }
        // This endpoint supports rendering groups and apps, for backwards
        // compatibility. This will be removed in the future
        switch (principal.type) {
            case 'user':
                ctx.response.body = userHal.item(principal, await privilegeService.getPrivilegesForPrincipal(principal), hasControl, hasPassword, isAdmin, await groupService.findGroupsForPrincipal(principal));
                break;
            case 'group': {
                const members = await groupService.findMembers(principal);
                ctx.response.body = groupHal.item(principal, await privilegeService.getPrivilegesForPrincipal(principal), isAdmin, await groupService.findGroupsForPrincipal(principal), members);
                break;
            }
            case 'app':
                ctx.response.body = appHal.item(principal, await privilegeService.getPrivilegesForPrincipal(principal), isAdmin, await groupService.findGroupsForPrincipal(principal));
                break;
        }
    }
    async put(ctx) {
        if (!await privilegeService.hasPrivilege(ctx, 'admin')) {
            throw new http_errors_1.Forbidden('Only users with the "admin" privilege may edit users');
        }
        ctx.request.validate('https://curveballjs.org/schemas/a12nserver/principal-edit.json');
        const user = await principalService.findById(+ctx.params.id);
        user.active = !!ctx.request.body.active;
        user.nickname = ctx.request.body.nickname;
        await principalService.save(user);
        ctx.status = 204;
    }
}
exports.default = new UserController();
//# sourceMappingURL=item.js.map