"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.hasTotp = exports.validateTotp = exports.hasPassword = exports.validatePassword = exports.updatePassword = exports.createPassword = void 0;
const bcrypt = require("bcrypt");
const otplib = require("otplib");
const database_1 = require("../database");
async function createPassword(user, password) {
    const query = 'INSERT INTO user_passwords SET user_id = ?, password = ?';
    await database_1.default.query(query, [
        user.id,
        await bcrypt.hash(password, 12)
    ]);
}
exports.createPassword = createPassword;
async function updatePassword(user, password) {
    const query = 'INSERT INTO user_passwords (password, user_id) VALUES (?, ?) ON DUPLICATE KEY UPDATE password = ?';
    const hashedPw = await bcrypt.hash(password, 12);
    await database_1.default.query(query, [hashedPw, user.id, hashedPw]);
}
exports.updatePassword = updatePassword;
/**
 * Returns true or false if the password was correct.
 *
 * Calling this method multiple times might result in a block.
 */
async function validatePassword(user, password) {
    const query = 'SELECT password FROM user_passwords WHERE user_id = ?';
    const result = await database_1.default.query(query, [user.id]);
    const hashes = result[0].map((row) => row.password);
    for (const hash of hashes) {
        if (await bcrypt.compare(password, hash.toString('utf-8'))) {
            return true;
        }
    }
    return false;
}
exports.validatePassword = validatePassword;
async function hasPassword(user) {
    const query = 'SELECT user_id FROM user_passwords WHERE user_id = ? LIMIT 1';
    const result = await database_1.default.query(query, [user.id]);
    return result[0].length > 0;
}
exports.hasPassword = hasPassword;
/**
 * Returns true or false if the totp token was correct.
 *
 * Calling this method multiple times might result in a block.
 */
async function validateTotp(user, token) {
    const query = 'SELECT secret FROM user_totp WHERE user_id = ?';
    const result = await database_1.default.query(query, [user.id]);
    if (!result[0].length) {
        // Not set up
        return false;
    }
    const secret = result[0][0].secret;
    return otplib.authenticator.check(token, secret);
}
exports.validateTotp = validateTotp;
/**
 * Returns true or false if the totp was provided or not.
 *
 *
 */
async function hasTotp(user) {
    const query = 'SELECT secret FROM user_totp WHERE user_id = ?';
    const result = await database_1.default.query(query, [user.id]);
    return result[0].length !== 0;
}
exports.hasTotp = hasTotp;
//# sourceMappingURL=service.js.map